PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.py File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions | Variables
utils.py File Reference

## Classes
class | pawpyseed.core.utils.PAWpyError
class | pawpyseed.core.utils.PAWpyWarning

## Namespaces
| pawpyseed.core.utils
| Main utilities file for the Python portion of the code.

## Functions
def | pawpyseed.core.utils.cfunc_call (func, outsize, args)
def | pawpyseed.core.utils.check_spin (spin, nspin)
def | pawpyseed.core.utils.cdouble_to_numpy (arr, length)
def | pawpyseed.core.utils.cfloat_to_numpy (arr, length)
def | pawpyseed.core.utils.numpy_to_cdouble (arr)
def | pawpyseed.core.utils.numpy_to_cfloat (arr)
def | pawpyseed.core.utils.numpy_to_cint (arr)
def | pawpyseed.core.utils.el (site)

## Variables
| pawpyseed.core.utils.c_int_p = POINTER(c_int)
| pawpyseed.core.utils.c_float_p = POINTER(c_float)
| pawpyseed.core.utils.c_double_p = POINTER(c_double)
| pawpyseed.core.utils.MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
| pawpyseed.core.utils.PAWC = CDLL(os.path.join(MODULE_DIR, "pawpy.so"))
| pawpyseed.core.utils.argtypes
| pawpyseed.core.utils.restype